==> ws-v3.70.10-src.tar.gz: ws-v3.70-10/include/WSCvmeter.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCVMETER_H
#define WSCVMETER_H

#include <WScom.h>
#include <WSCvpolyAttr.h>
#define WSCvmeter_VER  1010

class WSCvmeter   :public WSCvpolyAttr{

  protected:
    WSCuchar   _value1;
    WSCuchar   _value2;
    unsigned  _orientation:1;

    WSMFpropertyDef(WSNvalue1,      WSCuchar,_value1      );
    WSMFpropertyDef(WSNvalue2,      WSCuchar,_value2      );
    WSMFpropertyDef(WSNorientation, WSCbool, _orientation );

  public:
    WSCvmeter(WSCbase* base, char* name);
    virtual ~WSCvmeter();
    virtual long draw();
    virtual char* getDefaultProperty();

    WSMFguiClassDef( WSCvmeter, WSCvpolyAttr );
    WSMFversionDef  ( WSCvmeter );
};
#endif //WSCVMETER_H

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/WSCvmeter.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSCVMETER_H
#define WSCVMETER_H

#include <WScom.h>
#include <WSCvpolyAttr.h>
#define WSCvmeter_VER  1010

class WSCvmeter   :public WSCvpolyAttr{

  protected:
    WSCuchar   _value1;
    WSCuchar   _value2;
    unsigned  _orientation:1;

    WSMFpropertyDef(WSNvalue1,      WSCuchar,_value1      );
    WSMFpropertyDef(WSNvalue2,      WSCuchar,_value2      );
    WSMFpropertyDef(WSNorientation, WSCbool, _orientation );

  public:
    WSDLEX32 WSCvmeter(WSCbase* base, char* name);
    WSDLEX32 virtual ~WSCvmeter();
    WSDLEX32 virtual long draw();
    WSDLEX32 virtual char* getDefaultProperty();

    WSMFguiClassDef( WSCvmeter, WSCvpolyAttr );
    WSMFversionDef  ( WSCvmeter );
};
#endif //WSCVMETER_H
